==> gmt_6.5.0+dfsg.orig.tar.xz: gmt-6.5.0/src/longopt/sphdistance_inc.h <==
/*--------------------------------------------------------------------
 *
 *	Copyright (c) 1991-2024 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
 *	See LICENSE.TXT file for copying and redistribution conditions.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as published by
 *	the Free Software Foundation; version 3 or any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	Contact info: www.generic-mapping-tools.org
 *--------------------------------------------------------------------*/

#ifndef SPHDISTANCE_INC_H
#define SPHDISTANCE_INC_H

/* Translation table from long to short module options, directives and modifiers */

static struct GMT_KEYWORD_DICTIONARY module_kw[] = {
	/* separator, short_option, long_option,
		  short_directives,    long_directives,
		  short_modifiers,     long_modifiers,
		  transproc_mask */
	{ 0, 'A', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'C', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'D', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'E', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'G', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'I', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'L', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'N', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, 'Q', "",
	          "",                  "",
	          "",                  "",
		  GMT_TP_STANDARD },
	{ 0, '\0', "", "", "", "", "", 0 }  /* End of list marked with empty option and strings */
};
#endif  /* !SPHDISTANCE_INC_H */

==> gmt_6.6.0+dfsg.orig.tar.xz: gmt-6.6.0/src/longopt/sphdistance_inc.h <==
/*--------------------------------------------------------------------
 *
 *	Copyright (c) 1991-2025 by the GMT Team (https://www.generic-mapping-tools.org/team.html)
 *	See LICENSE.TXT file for copying and redistribution conditions.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as published by
 *	the Free Software Foundation; version 3 or any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	Contact info: www.generic-mapping-tools.org
 *--------------------------------------------------------------------*/

#ifndef SPHDISTANCE_INC_H
#define SPHDISTANCE_INC_H

/* Translation table from long to short module options, directives and modifiers */

static struct GMT_KEYWORD_DICTIONARY module_kw[] = {
	/* separator, short_option, long_option,
		  short_directives,    long_directives,
		  short_modifiers,     long_modifiers,
		  transproc_mask */
	{ 0, 'C', "save_mem|single_form", "", "", "", "", GMT_TP_STANDARD },
	{ 0, 'D', "duplicates|skipdup",   "", "", "", "", GMT_TP_STANDARD },
	{ 0, 'E', "quantity",
	          "d,n,z",             "distance,polygon,zvalue",
	          "",                  "",
		  GMT_TP_STANDARD },
	GMT_G_OUTGRID_KW,
	GMT_I_INCREMENT_KW,
	{ 0, 'L', "unit|dist_unit",    "", "", "", "", GMT_TP_STANDARD },
	{ 0, 'N', "nodes|node_table",  "", "", "", "", GMT_TP_STANDARD },
	{ 0, 'Q', "voronoi",           "", "", "", "", GMT_TP_STANDARD },
	{ 0, '\0', "", "", "", "", "", 0 }  /* End of list marked with empty option and strings */
};
#endif  /* !SPHDISTANCE_INC_H */
